
# This file is automatically generated by setup.py, So don't edit it. :)
VERSION_INFO = {
    'final': True,
    'version': '1.9.2',
    'branch_nick': '(detached',
    'revision_id': 'a38cc88df3008eda2afa0b00d93a4fb2ae2276cf',
    'revno': 4590
}
